#include <stdio.h>
#include <conio.h>

#include "xbeemicrolib.h"

/**
 * @brief Event handler code. This function is automatically called when Data Packet is received from XBee module.
 * This function is called in XBee_polling function. The polling function must be called periodically.
 */
void myOnRxPacket(const char* addr64, const char* addr16, const char* dat, const unsigned short size)
{
	printf("Rx(%s)\n", dat);
}

/**
 * @brief Host Record
 * Host record must be resoved by calling XBee_resolve function before using it (except Coordinator record, because it's special.)
 */
XBeeHostRecord enddevice = HOST_RECORD_INITIALIZER("ENDDEVICE");

/**
 * @brief main function.
 */
int main(int argc, char* argv[])
{
	/**
	 * Setup Xbee. Parameters of the network is configured in this function.
	 * Parameters can be changed by developer in "xbee_conf.h" file.
	 */
	XBee_setup();

	/**
	 * This function register the receive event handler.
	 */
	XBee_registerOnRxPacket(myOnRxPacket);

	/* Loop */
	while(1) {
		/* if keyboard is hit... */
		if(_kbhit()) {
			char c = _getch();
			if(c == 'R') { /* The hit key is 'R', resolve record. */
				XBee_resolve(&enddevice);
				XBee_waitResolveDone();
			} else { /* other, transmit the key code. */
				XBee_transmit(&enddevice, &c, 1);
			}
		}
		/**
		 * this function must be called periodically.
		 */
		XBee_polling();

	}
	return 0;
}

